diff mbox

AM35xx: Update the macro names

Message ID 1260356573-25242-1-git-send-email-premi@ti.com (mailing list archive)
State Superseded, archived
Delegated to: Tony Lindgren
Headers show

Commit Message

Sanjeev Premi Dec. 9, 2009, 11:02 a.m. UTC
None
diff --git a/arch/arm/plat-omap/include/plat/cpu.h b/arch/arm/plat-omap/include/plat/cpu.h
index 2e17890..8dd8801 100644
--- a/arch/arm/plat-omap/include/plat/cpu.h
+++ b/arch/arm/plat-omap/include/plat/cpu.h
@@ -399,8 +399,8 @@  IS_OMAP_TYPE(3517, 0x3517)
 						(omap3_has_sgx()) &&	\
 						(!omap3_has_iva()))
 # define cpu_is_omap3530()		(cpu_is_omap3430())
-# define cpu_is_omap3505()		is_omap3505()
-# define cpu_is_omap3517()		is_omap3517()
+# define cpu_is_am3505()		is_omap3505()
+# define cpu_is_am3517()		is_omap3517()
 # undef cpu_is_omap3630
 # define cpu_is_omap3630()		is_omap363x()
 #endif
diff mbox

Patch

diff --git a/arch/arm/mach-omap2/id.c b/arch/arm/mach-omap2/id.c
index 4fad192..9ab97ce 100644
--- a/arch/arm/mach-omap2/id.c
+++ b/arch/arm/mach-omap2/id.c
@@ -233,7 +233,7 @@  void __init omap3_check_revision(void)
 	case 0xb868:
 		/* Handle OMAP35xx/AM35xx devices
 		 *
 		 * Set the device to be OMAP3505 here. Actual device
 		 * is identified later based on the features.
 		 */
 		omap_revision = OMAP3505_REV(rev);
@@ -263,7 +263,7 @@  void __init omap3_cpuinfo(void)
 	 */
 	if (cpu_is_omap3630()) {
 		strcpy(cpu_name, "OMAP3630");
-	} else if (cpu_is_omap3505()) {
+	} else if (cpu_is_am3505()) {
 		/*
 		 * AM35xx devices
 		 */
@@ -233,7 +233,7 @@  void __init omap3_check_revision(void)
 		/* Handle OMAP35xx/AM35xx devices
 		 *
-		 * Set the device to be OMAP3505 here. Actual device
+		 * Set the device to be AM3505/OMAP3505 here. Actual device
 		 * is identified later based on the features.
 		 */